/****************************************************************************
 *                                                                          
 * Title:   Setting of Pulse Modulation with internal source
 *
 * Purpose: This example shows how to set Pulse Modulation parameters.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssism.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssism_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssism_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "USB::0xAAD::0x7::100001" // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;

    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssism_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Set Pulse Modulation  Parameters -----------------------------------\n\n"
    "\t- RF Frequency: 100 MHz\n"
    "\t- RF Level: -20.0 dBm\n"
    "\t- Modulation: Pulse\n"
    "\t- Modulation Source: Internal\n"
    "\t- Pulse Parameters: Off-Time = 10 ms, OnTime = 100 ms\n"
    "\t- Pulse Delay: 0 s\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    /* Configure RF Frequency */
    CHECKERR (rssism_configRFFreq (io, 1.0e8, 0.0, 1.0));
    /* Configure RF Level */
    CHECKERR (rssism_configRFLevel (io, -20.0, 0.0, 0.0));
    /* Set PM Source */
    CHECKERR (rssism_setPMSource (io, 0));
    /* Set PM Polarity */
    CHECKERR (rssism_setPMPolar (io, 0));
    /* Set PM Pulse Off Time */
    CHECKERR (rssism_setPMPulseOffTime (io, 10.0e-3));
    /* Set PM Pulse On Time */
    CHECKERR (rssism_setPMPulseOnTime (io, 100.0e-3));
    /* Set PM Pulse Delay Time */
    CHECKERR (rssism_setPMPulseDelayTime (io, 0.0));
    /* Set PM State */
    CHECKERR (rssism_setPMState (io, VI_TRUE));
    /* Set RF Output State */
    CHECKERR (rssism_setRFOutputState (io, VI_TRUE));

    printf ("\n");

    CHECKERR (rssism_close (io));

    return 0;
}
