/****************************************************************************
 *                                                                          
 * Title:   Setting of RF Frequency Sweep
 *
 * Purpose: This example shows how to set RF frequency sweep parameters.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssism.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssism_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssism_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "USB::0xAAD::0x7::100001" // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;

    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssism_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Set RF Frequency Sweep ---------------------------------------------\n\n"
    "\t- RF Start Frequency: 100 MHz\n"
    "\t- RF Stop Frequency: 500 MHz\n"
    "\t- Step Width: 1 MHz\n"
    "\t- Dwell Time: 0.01 s\n"
    "\t- RF Level: -20.0 dBm\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    /* Configure RF Level */
    CHECKERR (rssism_configRFLevel (io, -20.0, 0.0, 0.0));
    /* Configure RF Frequency Sweep */
    CHECKERR (rssism_configRFFreqSweep (io, 0, 100.0e6, 500.0e6, 1.0e6, 0.01));
    /* Set Sweep Trigger Source */  
    CHECKERR (rssism_setSweepTrigSource (io, 1, 2));
    /* Set RF Output State */
    CHECKERR (rssism_setRFOutputState (io, VI_TRUE));

    printf ("\n");

    CHECKERR (rssism_close (io));

    return 0;
}
